import { S as SvelteComponent, i as init, s as safe_not_equal } from './index.20bd6624.js';

/* src/components/Variable/Variable.svelte generated by Svelte v3.49.0 */

class Variable extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, null, null, safe_not_equal, {});
	}
}

var Variable$1 = Variable;

const modes = ["static"];

export { Variable$1 as Component, modes };
